<?php
/**
 * Created by PhpStorm.
 * User: matheussilva
 * Date: 30/10/14
 * Time: 11:45
 */

namespace Folha\Logic\ESocial\Importacao;

class ImportacaoLeiaute
{
    private $diretorio;
    private $arquivo;
    private $versao;

    const XLS = 1;
    const XLSX = 2;

    /**
     * @param $caminho          Pasta na qual se encontram os arquivos de leiaute
     * @param $versao           Versão do E-Social
     * @param $arq_eventos      Nome do arquivo com a descrição dos eventos
     * @param $arq_resumos      Nome do arquivo com os resumos dos eventos
     * @param $arq_registros    Nome dos arquivos com os registros do eventos
     * @throws \Exception
     */
    public function __construct($caminho, $versao, $arquivo)
    {
        try {
            $this->validaExtensao("$caminho\\$arquivo");

            $this->diretorio = $caminho;
            $this->arquivo = $arquivo;
            $this->versao = $versao;

        } catch (\Exception $e) {
            if($e->getCode() == Exception::AVISO){
                tk_message($e->getMessage(), 'error');
            }else{
                throw $e;
            }
        }
    }

    public function preparaInformacao()
    {
        try {
            $handle = new ManipulacaoExcel($this->diretorio."\\".$this->arquivo);
            $info = $handle->preparaDados();

            $persist = new Persistencia($info);
            $persist->persisteTabelas($this->versao);

            return "Leiautes gerados com sucesso!!!";
        } catch (\Exception $e) {
            if($e->getCode() == Exception::AVISO){
                tk_message($e->getMessage(), 'error');
            }else{
                throw $e;
            }
        }
    }

    /**
     * Validador de Extensão de Arquivo.
     *
     * @param $caminho
     *
     * @return bool
     * @throws \Exception
     */
    private function validaExtensao( $caminho)
    {
        try {
            $nome = preg_split("/(\\|\/|\.)/", $caminho);
            $extencao = strtoupper(end($nome));
            switch ($extencao) {
                case('XLS'):{
                    return self::XLS;
                }
                case('XLSX'):{
                    return self::XLSX;
                }
                default:{
                    throw Exception::extensaoInvalida();
                }
            }
        } catch (\Exception $e) {
            if($e->getCode() == Exception::AVISO){
                tk_message($e->getMessage(), 'error');
            }else{
                throw $e;
            }
        }
    }
}